/*****************************************************************************
 *
 * libwsw, Copyright (C) 2007 by Alexander Tsvyashchenko
 * contact address: <ejabberd@ndl.kiev.ua>
 *
 * short license info is below, but it concerns only program itself -
 * you should see copyrights.txt for algorithms licenses info!
 *
 *****************************************************************************

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

******************************************************************************/

#include "stdafx.h"
#include "utils.h"

//--------------------------------------------------------------------------------
using namespace boost::posix_time;
using namespace WSW::DateTime;
//--------------------------------------------------------------------------------
const TimeType WSW::DateTime::TIME_INVALID = not_a_date_time;
const TimeType WSW::DateTime::INF_NEG = neg_infin;
//--------------------------------------------------------------------------------
namespace
  {
  // boost::date_time does not provide it ???
  ptime from_iso_extended_string(const std::string& s)
    {
    typedef ptime::time_duration_type time_duration;
    typedef ptime::date_type date_type;

    //split date/time on a unique delimiter char such as ' ' or 'T'
    std::string date_string, tod_string;
    boost::date_time::split(s, 'T', date_string, tod_string);
    //call parse_date with first string
    date_type d = boost::date_time::parse_date<date_type>(date_string);
    //call parse_time_duration with remaining string
    time_duration td = boost::date_time::parse_delimited_time_duration<time_duration>(tod_string);
    //construct a time
    return ptime(d, td);
    }
  }
//--------------------------------------------------------------------------------
TimeType WSW::DateTime::str2DateTime(const std::string& str)
  {
  std::string::size_type pos = str.find_last_of("Z");
  if (pos != std::string::npos)
    return from_iso_extended_string(str.substr(0, pos));
  else
    return from_iso_extended_string(str);
  }
//--------------------------------------------------------------------------------
std::string WSW::DateTime::dateTime2Str(const TimeType& time)
  {
  return to_iso_extended_string(time) + "Z";
  }
//--------------------------------------------------------------------------------
TimeType WSW::DateTime::now()
  {
  return microsec_clock::universal_time();
  }
//--------------------------------------------------------------------------------
