/*****************************************************************************
 *
 * libwsw, Copyright (C) 2007 by Alexander Tsvyashchenko
 * contact address: <ejabberd@ndl.kiev.ua>
 *
 * short license info is below, but it concerns only program itself -
 * you should see copyrights.txt for algorithms licenses info!
 *
 *****************************************************************************

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

******************************************************************************/

#ifndef WSW_UTILS_H
#define WSW_UTILS_H
//------------------------------------------------------------------------------
#include <boost/date_time/posix_time/posix_time.hpp>

#ifdef USE_SOCI
#include <soci.h>
#endif
//------------------------------------------------------------------------------
namespace WSW
  {
  namespace DateTime
    {
    typedef boost::posix_time::ptime TimeType;
    extern const TimeType TIME_INVALID;
    extern const TimeType INF_NEG;

    TimeType str2DateTime(const std::string& str);
    std::string dateTime2Str(const TimeType& date_time);
    TimeType now();
    };
  namespace Math
    {
    template <class Number>
    inline short sign(Number num)
      {
      if (num < 0) return -1;
      if (num > 0) return 1;
      return 0;
      }
    }
  namespace XMPP
    {
    inline const std::string getBareJID(const std::string& jid)
      {
      std::string::size_type pos = jid.find('/');
      if (pos == std::string::npos)
        return jid;
      else
        return jid.substr(0, pos);
      }
    }
  }
//------------------------------------------------------------------------------
#ifdef USE_SOCI
namespace SOCI
  {
  template<>
  struct TypeConversion<boost::posix_time::ptime>
    {
    typedef std::tm base_type;
    inline static boost::posix_time::ptime from(std::tm& t)
      {
      return boost::posix_time::ptime_from_tm(t);
      }

    inline static std::tm to(boost::posix_time::ptime& t)
      {
      return boost::posix_time::to_tm(t);
      }
    };
  }
#endif // USE_SOCI
//------------------------------------------------------------------------------
#endif // WSW_UTILS_H
